==> wls-plugin-1.2.2.jar: com/xebialabs/deployit/plugin/wls/step/destroy-datasource.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

sys.argv.pop(0)
username = sys.argv.pop(0)
password = sys.argv.pop(0)
connectionURL = sys.argv.pop(0)
dsName = sys.argv.pop(0)

connect(username, password, connectionURL)
edit()
startEdit()

jdbcSR = getMBean('/JDBCSystemResources/'+dsName)
if jdbcSR is None:
	print "DataSource with name : "+dsName+' does not exist, doing nothing.'
	disconnect()
	exit()

delete(dsName,'JDBCSystemResource')
print 'Deleted data source with name : '+dsName+ ' successfully'

save()
disconnect('true')
exit('y')

==> wls-plugin-1.4.jar: com/xebialabs/deployit/plugin/wls/step/destroy-datasource.py <==
#
# Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

sys.argv.pop(0)
username = sys.argv.pop(0)
password = sys.argv.pop(0)
connectionURL = sys.argv.pop(0)
dsName = sys.argv.pop(0)

print "Connecting to WebLogic"
connect(username, password, connectionURL)
edit()
startEdit()

jdbcSR = getMBean('/JDBCSystemResources/'+dsName)
if jdbcSR is None:
	print "Data source with name : "+dsName+' does not exist. Doing nothing.'
	disconnect('true')
	exit('y')

print "Deleting data source " + dsName
delete(dsName,'JDBCSystemResource')

print "Saving configuration"
save()
disconnect('true')
exit('y')
